<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>ActionPackSystem</name>
    <message>
        <location filename="../actions/actionpacksystem/actionpacksystem.h" line="72"/>
        <source>Actions dealing with the operating system</source>
        <translation>Actions en rapport avec le système d&apos;exploitation</translation>
    </message>
</context>
<context>
    <name>Actions::CommandDefinition</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="46"/>
        <source>Command</source>
        <translation>Commande</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="47"/>
        <source>The command to execute</source>
        <translation>La commande à exécuter</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="50"/>
        <source>Parameters</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="51"/>
        <source>The command&apos;s parameters</source>
        <translation>Les paramètres de la commande</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="54"/>
        <source>Working directory</source>
        <translation>Dossier de travail</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="55"/>
        <source>The command&apos;s working directory</source>
        <translation>Le dossier de travail de la commande</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="56"/>
        <source>Command working directory</source>
        <translation>Dossier de travail de la commande</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="60"/>
        <source>Exit code</source>
        <translation>Code de sortie</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="61"/>
        <source>The command&apos;s exit code</source>
        <translation>Le code de sortie de la commande</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="64"/>
        <source>Process id</source>
        <translation>Identifiant de processus</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="65"/>
        <source>The command&apos;s process id</source>
        <translation>L&apos;identifiant de processus de la commande</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="68"/>
        <source>Output</source>
        <translation>Sortie</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="69"/>
        <source>The command&apos;s output</source>
        <translation>La sortie de la commande</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="72"/>
        <source>Error output</source>
        <translation>Sortie d&apos;erreur</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="73"/>
        <source>The command&apos;s error output</source>
        <translation>La sortie d&apos;erreur de la commande</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="76"/>
        <source>Exit status</source>
        <translation>Statut de sortie</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="77"/>
        <source>The command&apos;s exit status</source>
        <translation>Le statut de sortie de la commande</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="80"/>
        <source>Failed to start the command</source>
        <translation>Impossible d&apos;exécuter la commande</translation>
    </message>
</context>
<context>
    <name>Actions::CommandInstance</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/commandinstance.h" line="114"/>
        <source>Failed to start the command. %1</source>
        <translation>Impossible d&apos;exécuter la commande. %1</translation>
    </message>
</context>
<context>
    <name>Actions::DetachedCommandDefinition</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="46"/>
        <source>Command</source>
        <translation>Commande</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="47"/>
        <source>The command to execute</source>
        <translation>La commande à exécuter</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="50"/>
        <source>Parameters</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="51"/>
        <source>The command&apos;s parameters</source>
        <translation>Les paramètres de la commande</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="54"/>
        <source>Working directory</source>
        <translation>Dossier de travail</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="55"/>
        <source>The command&apos;s working directory</source>
        <translation>Le dossier de travail de la commande</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="56"/>
        <source>Command working directory</source>
        <translation>Dossier de travail de la commande</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="60"/>
        <source>Process id</source>
        <translation>Identifiant de processus</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="61"/>
        <source>The command&apos;s process id</source>
        <translation>L&apos;identifiant de processus de la commande</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="64"/>
        <source>Unable to execute the detached command</source>
        <translation>Impossible d&apos;exécuter la commande détachée</translation>
    </message>
</context>
<context>
    <name>Actions::DetachedCommandInstance</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommandinstance.h" line="66"/>
        <source>Unable to start the detached command</source>
        <translation>Impossible d&apos;exécuter la commande détachée</translation>
    </message>
</context>
<context>
    <name>Actions::FindImageDefinition</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="57"/>
        <source>Source</source>
        <translation>Source</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="58"/>
        <source>The source of the image to search in</source>
        <translation>La source de l&apos;image où chercher</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="67"/>
        <source>Window name</source>
        <translation>Titre de fenêtre</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="68"/>
        <source>The title of the window to search in, you can use wildcards like * (any number of characters) or ? (one character) here</source>
        <translation>Le titre de la fenêtre où chercher, vous pouvez utiliser des wildcards ici comme * (n&apos;importe quel nombre de caractères) ou ? (un caractère)</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="81"/>
        <source>Image to search in</source>
        <translation>Image où chercher</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="82"/>
        <source>The image to search in</source>
        <translation>L&apos;image où chercher</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="84"/>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="93"/>
        <source>Choose an image file</source>
        <translation>Choisissez un fichier image</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="85"/>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="94"/>
        <source>Image files (*.bmp *.gif *.jpg *.jpeg *.mng *.png *.pbm *.pgm *.ppm *.tiff *.xbm *.xpm *.svg)
All files (*.*)</source>
        <translation>Images (*.bmp *.gif *.jpg *.jpeg *.mng *.png *.pbm *.pgm *.ppm *.tiff *.xbm *.xpm *.svg)
Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="90"/>
        <source>Image to find</source>
        <translation>Image à chercher</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="91"/>
        <source>The image to search for</source>
        <translation>l&apos;image à chercher</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="97"/>
        <source>If found</source>
        <translation>Si trouvé</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="98"/>
        <source>What to do if the image is found</source>
        <translation>Ce qui doit être fait si l&apos;image a été trouvée</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="102"/>
        <source>If not found</source>
        <translation>Si non trouvé</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="103"/>
        <source>What to do if the image is not found</source>
        <translation>Ce qui doit être fait si l&apos;image n&apos;a pas été trouvée</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="107"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="108"/>
        <source>The name of the variable where to store the coordinates of the center of the found image</source>
        <translation>Le nom de la variable où stocker les coordonnées du centre de l&apos;image trouvée</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="124"/>
        <source>Maximum amount of images to find</source>
        <translation>Nombre maximum d&apos;images à chercher</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="125"/>
        <source>The maximum amount of images to find
Setting this parameter higher will increase the search duration</source>
        <translation>Le nombre maximum d&apos;images à chercher
Choisir une valeur élevée pour ce paramètre va augmenter la durée de la recherche</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="131"/>
        <source>Downsampling</source>
        <translation>Sous-échantillonnage</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="132"/>
        <source>The downsampling value to use
Downsampling is used to accelerate the search when using large images</source>
        <translation>La valeur de sous-échantillonnage à utiliser
Le sous-échantillonnage sert à accélérer la recherche lors d&apos;une recherche sur de grandes images</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="71"/>
        <source>Window relative position</source>
        <translation>Position relative à la fenêtre</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="72"/>
        <source>The position is relative to the window
If this parameter is set to false (not checked) then the position is absolute</source>
        <translation>La position est-elle relative à la fenêtre
Si ce paramètre est faux (non coché) alors la position est absolue</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="111"/>
        <source>Method</source>
        <translation>Méthode</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="112"/>
        <source>The matching method to use</source>
        <translation>La méthode de recherche à utiliser</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="117"/>
        <source>Confidence minimum</source>
        <translation>Confiance minimale</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="118"/>
        <source>The minimum confidence percentage required to select a possible matching image</source>
        <translation>Le pourcentage minimum de confiance nécessaire pour sélectionner un résultat possible</translation>
    </message>
    <message>
        <source>Maximum matches</source>
        <translation type="vanished">Nombre maximum de résultats</translation>
    </message>
    <message>
        <source>The maximum matching images count
Setting this parameter higher will increase the duration of the search</source>
        <translation type="vanished">Le nombre maximum de résultats
Choisir une valeur élevée pour ce paramètre va augmenter la durée de la recherche</translation>
    </message>
    <message>
        <source>Down pyramid count</source>
        <translation type="obsolete">Nombre de pyramides descendantes</translation>
    </message>
    <message>
        <source>The number of down pyramids to use
A pyramid is a subdivision of the image used to accelerate the search
Enter 1 here if the searched image is not very different from the source image</source>
        <translation type="obsolete">Le nombre de pyramides descendantes à utiliser
Une pyramide est une subdivision de l&apos;image utilisée pour accélérer la recherche
Entrez 1 ici si l&apos;image recherchée n&apos;est pas très différente de l&apos;image source</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="138"/>
        <source>Search expansion</source>
        <translation>Expansion de la recherche</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="139"/>
        <source>The number of pixels to shift when searching for another matching image</source>
        <translation>Le décalage en pixels à effectuer lors de la recherche d&apos;une autre solution possible</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="145"/>
        <source>Delay between two searches when waiting</source>
        <translation>Délai entre deux recherches lors d&apos;une attente</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="146"/>
        <source>The delay between two searches</source>
        <translation>Le délai entre deux recherches lors d&apos;une attente</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="150"/>
        <source> ms</source>
        <comment>milliseconds</comment>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="153"/>
        <source>Confidence</source>
        <translation>Confiance</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="154"/>
        <source>The name of the variable where to store the confidence value found image</source>
        <translation>Le nom de la variable où stocker la confiance en l&apos;image trouvée</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="157"/>
        <source>Error while searching</source>
        <translation>Erreur lors de la recherche</translation>
    </message>
    <message>
        <source>Cannot find the image</source>
        <translation type="obsolete">Impossible de trouver l&apos;image</translation>
    </message>
</context>
<context>
    <name>Actions::FindImageInstance</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="87"/>
        <source>minimum confidence</source>
        <translation>confiance minimum</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="88"/>
        <source>maximum matches</source>
        <translation>nombre maximum de résultats</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="97"/>
        <source>Invalid image to find</source>
        <translation>Image à chercher invalide</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="155"/>
        <source>Invalid image to search in</source>
        <translation>Image où chercher invalide</translation>
    </message>
    <message>
        <source>down pyramid count</source>
        <translation type="obsolete">nombre de pyramides descendantes</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="89"/>
        <source>downsampling</source>
        <translation>sous-échantillonnage</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="90"/>
        <source>search expansion</source>
        <translation>expansion de la recherche</translation>
    </message>
    <message>
        <source>Unable to load image to find from file %1</source>
        <translation type="obsolete">Impossible de charger l&apos;image à trouver à partir du fichier %1</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="136"/>
        <source>Unable to find any window named %1</source>
        <translation>Impossible de trouver une fenêtre nommée %1</translation>
    </message>
    <message>
        <source>Unable to take a screenshot of the window named %1</source>
        <translation type="obsolete">Impossible de prendre une capture d&apos;écran de la fenêtre nommée %1</translation>
    </message>
    <message>
        <source>Unable to load image to search in from file %1</source>
        <translation type="obsolete">Impossible de charger l&apos;image où chercher à partir du fichier %1</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="180"/>
        <source>Error while searching: %1</source>
        <translation>Erreur lors de la recherche : %1</translation>
    </message>
    <message>
        <source>Cannot find the image</source>
        <translation type="obsolete">Impossible de trouver l&apos;image</translation>
    </message>
    <message>
        <source>Invalid %1 value : %2</source>
        <translation type="vanished">Valeur %1 incorrecte : %2</translation>
    </message>
</context>
<context>
    <name>Actions::KillProcessDefinition</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/killprocessdefinition.h" line="50"/>
        <source>Process id</source>
        <translation>Identifiant de processus</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/killprocessdefinition.h" line="51"/>
        <source>The process id of the process to kill</source>
        <translation>L&apos;identifiant de processus du processus à fermer</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/killprocessdefinition.h" line="54"/>
        <source>Kill mode</source>
        <translation>Mode de fermeture</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/killprocessdefinition.h" line="55"/>
        <source>The kill mode</source>
        <translation>Le mode de fermeture</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/killprocessdefinition.h" line="60"/>
        <source>Timeout</source>
        <translation>Délai</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/killprocessdefinition.h" line="61"/>
        <source>The timeout before doing a forceful kill</source>
        <translation>Délai avant de fermer de façon brutale</translation>
    </message>
</context>
<context>
    <name>Actions::NotifyDefinition</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifydefinition.h" line="48"/>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifydefinition.h" line="49"/>
        <source>The notification title</source>
        <translation>Titre de la notification</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifydefinition.h" line="52"/>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifydefinition.h" line="53"/>
        <source>The notification text</source>
        <translation>Texte de la notification</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifydefinition.h" line="56"/>
        <source>Timeout</source>
        <translation>Délai</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifydefinition.h" line="57"/>
        <source>The notification timeout</source>
        <translation>Délai de la notification</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifydefinition.h" line="63"/>
        <source>Icon</source>
        <translation>Icône</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifydefinition.h" line="64"/>
        <source>The notification icon</source>
        <translation>L&apos;icône de la notification</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifydefinition.h" line="67"/>
        <source>Show notification failure</source>
        <translation>Erreur lors de l&apos;affichage de la notification</translation>
    </message>
</context>
<context>
    <name>Actions::NotifyInstance</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifyinstance.cpp" line="81"/>
        <source>Unable to show the notification</source>
        <translation>Impossible d&apos;afficher la notification</translation>
    </message>
</context>
<context>
    <name>Actions::OpenURLDefinition</name>
    <message>
        <source>Scheme</source>
        <translation type="obsolete">Schéma</translation>
    </message>
    <message>
        <source>The url scheme</source>
        <translation type="obsolete">Le schéma de l&apos;URL</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/openurldefinition.h" line="44"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/openurldefinition.h" line="45"/>
        <source>The url to open</source>
        <translation>L&apos;URL à ouvrir</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/openurldefinition.h" line="48"/>
        <source>Failed to open URL</source>
        <translation>Impossible d&apos;ouvrir l&apos;URL</translation>
    </message>
</context>
<context>
    <name>Actions::OpenURLInstance</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/openurlinstance.h" line="59"/>
        <location filename="../actions/actionpacksystem/actions/openurlinstance.h" line="68"/>
        <source>Failed to open URL</source>
        <translation>Impossible d&apos;ouvrir l&apos;URL</translation>
    </message>
</context>
<context>
    <name>Actions::PixelColorDefinition</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="51"/>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="52"/>
        <source>The pixel position and color to check</source>
        <translation>La position et la couleur du pixel à vérifier</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="55"/>
        <source>Comparison</source>
        <translation>Comparaison</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="56"/>
        <source>The comparison</source>
        <translation>La comparaison</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="61"/>
        <source>If true</source>
        <translation>Si vrai</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="62"/>
        <source>What to to if the pixel comparison is true</source>
        <translation>Ce qui doit être fait si la comparaison de pixel est vraie</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="65"/>
        <source>If false</source>
        <translation>Si faux</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="66"/>
        <source>What to to if the pixel comparison is false</source>
        <translation>Ce qui doit être fait si la comparaison de pixel est fausse</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="70"/>
        <source>Pixel color variable</source>
        <translation>Variable de la couleur de pixel</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="71"/>
        <source>Variable name where to store the pixel color</source>
        <translation>Nom de la variable où stocker la couleur du pixel</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="74"/>
        <source>Red tolerance</source>
        <translation>Tolérance du rouge</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="75"/>
        <source>The tolerance percentage for the red color component</source>
        <translation>Le pourcentage de tolérance pour le composant rouge</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="81"/>
        <source>Green tolerance</source>
        <translation>Tolérance du vert</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="82"/>
        <source>The tolerance percentage for the green color component</source>
        <translation>Le pourcentage de tolérance pour le composant vert</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="88"/>
        <source>Blue tolerance</source>
        <translation>Tolérance du bleu</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="89"/>
        <source>The tolerance percentage for the blue color component</source>
        <translation>Le pourcentage de tolérance pour le composant bleu</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="95"/>
        <source>Offset</source>
        <translation>Décalage</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="96"/>
        <source>The offset to apply to the pixel position</source>
        <translation>Le décalage à appliquer à la position du pixel</translation>
    </message>
</context>
<context>
    <name>Actions::PlaySoundDefinition</name>
    <message>
        <source>Sound file/url</source>
        <translation type="obsolete">Fichier/Url</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="48"/>
        <source>Sound file/URL</source>
        <translation>Fichier son/URL</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="49"/>
        <source>The sound file or URL to play</source>
        <translation>Le fichier son ou l&apos;URL à jouer</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="51"/>
        <source>Choose the sound file</source>
        <translation>Choisissez le fichier son</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="52"/>
        <source>All files (*.*)</source>
        <translation>Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="55"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="56"/>
        <source>Is the sound resource an URL</source>
        <translation>La ressource est-elle une URL</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="60"/>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="61"/>
        <source>The volume to play at</source>
        <translation>Le volume à utiliser</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="64"/>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="82"/>
        <source>%</source>
        <comment>percent</comment>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="68"/>
        <source>Wait until played</source>
        <translation>Attendre fin de lecture</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="69"/>
        <source>Should the action end only when the sound has finished playing</source>
        <translation>Attendre la fin de la lecture avant de terminer l&apos;action</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="73"/>
        <source>Looping</source>
        <translation>Jouer en boucle</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="74"/>
        <source>Should the sound loop</source>
        <translation>Jouer en son en boucle</translation>
    </message>
    <message>
        <source>Distant</source>
        <translation type="obsolete">Distant</translation>
    </message>
    <message>
        <source>Is the sound resource distant</source>
        <translation type="obsolete">Le son est distant</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="78"/>
        <source>Playback rate</source>
        <translation>Vitesse de lecture</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="79"/>
        <source>The playback rate</source>
        <translation>La vitesse de lecture</translation>
    </message>
</context>
<context>
    <name>Actions::PlaySoundInstance</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsoundinstance.cpp" line="67"/>
        <source>Unable to load file %1: %2</source>
        <translation>Impossible de charger le fichier %1 : %2</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsoundinstance.cpp" line="79"/>
        <source>Unable to play file %1: %2</source>
        <translation>Impossible de lire le fichier %1 : %2</translation>
    </message>
</context>
<context>
    <name>Actions::SystemDefinition</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/systemdefinition.h" line="49"/>
        <source>Operation</source>
        <translation>Opération</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systemdefinition.h" line="50"/>
        <source>The operation to execute</source>
        <translation>L&apos;opération à exécuter</translation>
    </message>
    <message>
        <source>Operation mode</source>
        <translation type="obsolete">Mode</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systemdefinition.h" line="64"/>
        <source>Force</source>
        <translation>Forcer</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systemdefinition.h" line="65"/>
        <source>Should the operation be forced</source>
        <translation>L&apos;opération doit-elle être forcée</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation type="obsolete">Mode</translation>
    </message>
    <message>
        <source>The operation mode</source>
        <translation type="obsolete">Le mode de l&apos;opération</translation>
    </message>
    <message>
        <source>Not enough rights</source>
        <translation type="obsolete">Pas assez de droits</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systemdefinition.h" line="71"/>
        <source>Not available</source>
        <translation>Non disponible</translation>
    </message>
</context>
<context>
    <name>Actions::SystemInstance</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="54"/>
        <source>Logout is not available</source>
        <translation>La déconnexion n&apos;est pas disponible</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation type="obsolete">Déconnexion</translation>
    </message>
    <message>
        <source>Do you really want to logout ?</source>
        <translation type="obsolete">Voulez-vous vraiment vous déconnecter ?</translation>
    </message>
    <message>
        <source>Not enough rights to logout</source>
        <translation type="obsolete">Pas assez de droits pour se déconnecter</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="61"/>
        <source>Restart is not available</source>
        <translation>Le redémarrage n&apos;est pas disponible</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="75"/>
        <source>Suspend is not available</source>
        <translation>La mise en veille n&apos;est pas disponible</translation>
    </message>
    <message>
        <source>Suspend failed</source>
        <translation type="obsolete">Mise en veille échouée</translation>
    </message>
    <message>
        <source>Hibernate failed</source>
        <translation type="obsolete">Mise en hibernation échouée</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="82"/>
        <source>Hibernate is not available</source>
        <translation>La mise en hibernation n&apos;est pas disponible</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="89"/>
        <source>Lock is not available</source>
        <translation>Le verrouillage de session n&apos;est pas disponible</translation>
    </message>
    <message>
        <source>Not enough rights to lock</source>
        <translation type="obsolete">Droits insuffisants pour verrouiller</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="96"/>
        <source>Start screen saver is not available</source>
        <translation>Impossible de démarrer l&apos;écran de veille</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation type="obsolete">Redémarrer</translation>
    </message>
    <message>
        <source>Do you really want to restart ?</source>
        <translation type="obsolete">Voulez-vous vraiment redémarrer ?</translation>
    </message>
    <message>
        <source>Not enough rights to restart</source>
        <translation type="obsolete">Pas assez de droits pour redémarrer</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="68"/>
        <source>Shutdown is not available</source>
        <translation>L&apos;arrêt n&apos;est pas disponible</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation type="obsolete">Arrêt</translation>
    </message>
    <message>
        <source>Do you really want to shutdown ?</source>
        <translation type="obsolete">Voulez-vous vraiment arrêter votre ordinateur ?</translation>
    </message>
    <message>
        <source>Not enough rights to shutdown</source>
        <translation type="obsolete">Pas assez de droits pour arrêter l&apos;ordinateur</translation>
    </message>
</context>
<context>
    <name>Code::MediaPlaylist</name>
    <message>
        <location filename="../actions/actionpacksystem/code/mediaplaylist.cpp" line="161"/>
        <location filename="../actions/actionpacksystem/code/mediaplaylist.cpp" line="172"/>
        <source>Add media failed : %1</source>
        <translation>Impossible d&apos;ajouter le média : %1</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/mediaplaylist.cpp" line="183"/>
        <location filename="../actions/actionpacksystem/code/mediaplaylist.cpp" line="194"/>
        <source>Insert media failed : %1</source>
        <translation>Impossible d&apos;insérer le média : %1</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/mediaplaylist.cpp" line="205"/>
        <source>Clear failed : %1</source>
        <translation>Impossible de vider la liste de lecture : %1</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/mediaplaylist.cpp" line="251"/>
        <source>Remove media failed : %1</source>
        <translation>Impossible de supprimer un média : %1</translation>
    </message>
</context>
<context>
    <name>Code::Notify</name>
    <message>
        <location filename="../actions/actionpacksystem/code/notify.cpp" line="110"/>
        <source>Unable to show the notification</source>
        <translation>Impossible d&apos;afficher la notification</translation>
    </message>
</context>
<context>
    <name>Code::Process</name>
    <message>
        <location filename="../actions/actionpacksystem/code/process.cpp" line="90"/>
        <location filename="../actions/actionpacksystem/code/process.cpp" line="161"/>
        <source>Invalid filename</source>
        <translation>Nom de fichier incorrect</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/process.cpp" line="112"/>
        <source>Unable to start the process</source>
        <translation>Impossible de démarrer le processus</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/process.cpp" line="251"/>
        <location filename="../actions/actionpacksystem/code/process.cpp" line="256"/>
        <location filename="../actions/actionpacksystem/code/process.cpp" line="265"/>
        <source>Write failed</source>
        <translation>Impossible d&apos;écrire</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/process.cpp" line="351"/>
        <source>Invalid process</source>
        <translation>Processus incorrect</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/process.cpp" line="363"/>
        <source>Wait for finished failed</source>
        <translation>L&apos;attente de terminaison a échouée</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/process.cpp" line="371"/>
        <source>Wait for started failed</source>
        <translation>L&apos;attente de démarrage a échouée</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/process.cpp" line="379"/>
        <source>Waiting for bytes written failed</source>
        <translation>L&apos;attente d&apos;écriture a échouée</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/process.cpp" line="387"/>
        <source>Waiting for ready read failed</source>
        <translation>L&apos;attente de lecture a échouée</translation>
    </message>
</context>
<context>
    <name>Code::System</name>
    <message>
        <location filename="../actions/actionpacksystem/code/system.cpp" line="103"/>
        <source>Cannot open the url</source>
        <translation>Impossible d&apos;ouvrir l&apos;url</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/system.cpp" line="337"/>
        <source>Logout failed</source>
        <translation>Échec de la déconnexion</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/system.cpp" line="345"/>
        <source>Restart failed</source>
        <translation>Échec du redémarrage</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/system.cpp" line="353"/>
        <source>Shutdown failed</source>
        <translation>Échec de l&apos;extinction</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/system.cpp" line="361"/>
        <source>Suspend failed</source>
        <translation>Échec de la mise en veille</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/system.cpp" line="369"/>
        <source>Hibernate failed</source>
        <translation>Échec de la mise en hibernation</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/system.cpp" line="377"/>
        <source>Lock screen failed</source>
        <translation>Échec du verrouillage de l&apos;écran</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/code/system.cpp" line="385"/>
        <source>Start screen saver failed</source>
        <translation>Échec du démarrage de l&apos;écran de veille</translation>
    </message>
</context>
<context>
    <name>FindImageInstance::sources</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="35"/>
        <source>Screenshot</source>
        <translation>Capture d&apos;écran</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="36"/>
        <source>Window</source>
        <translation>Fenêtre</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="37"/>
        <source>Image</source>
        <translation>Image</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="41"/>
        <source>Correlation Coefficient</source>
        <translation>Coefficient de corrélation</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="42"/>
        <source>Cross Correlation</source>
        <translation>Corrélation croisée</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimageinstance.cpp" line="43"/>
        <source>Squared Difference</source>
        <translation>Différence de carrés</translation>
    </message>
</context>
<context>
    <name>KillProcessInstance::killModes</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/killprocessinstance.cpp" line="28"/>
        <source>Graceful</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/killprocessinstance.cpp" line="29"/>
        <source>Forceful</source>
        <translation>Forcé</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/killprocessinstance.cpp" line="30"/>
        <source>Graceful then forceful</source>
        <translation>Normal puis forcé</translation>
    </message>
</context>
<context>
    <name>PixelColorInstance::comparisons</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolorinstance.cpp" line="28"/>
        <source>Equal</source>
        <translation>Égal</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolorinstance.cpp" line="29"/>
        <source>Darker</source>
        <translation>Plus sombre</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolorinstance.cpp" line="30"/>
        <source>Lighter</source>
        <translation>Plus clair</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="83"/>
        <source>Command</source>
        <translation>Commande</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/commanddefinition.h" line="86"/>
        <source>Executes a command</source>
        <translation>Exécute une commande</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/killprocessdefinition.h" line="68"/>
        <source>Kill process</source>
        <translation>Fermer processus</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/killprocessdefinition.h" line="71"/>
        <source>Kills a process</source>
        <translation>Ferme un processus</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifydefinition.h" line="70"/>
        <source>Notify</source>
        <translation>Notification</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/notifydefinition.h" line="73"/>
        <source>Shows a message using the notify system</source>
        <translation>Affiche un message via le système de notifications</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="100"/>
        <source>Pixel color</source>
        <translation>Couleur de pixel</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/pixelcolordefinition.h" line="103"/>
        <source>Check a pixel color on the screen</source>
        <translation>Vérifie la couleur d&apos;un pixel sur l&apos;écran</translation>
    </message>
    <message>
        <source>Graceful</source>
        <translation type="obsolete">Normal</translation>
    </message>
    <message>
        <source>Forceful</source>
        <translation type="obsolete">Forcé</translation>
    </message>
    <message>
        <source>Graceful then forceful</source>
        <translation type="obsolete">Normal puis forcé</translation>
    </message>
    <message>
        <source>Equal</source>
        <translation type="obsolete">Égal</translation>
    </message>
    <message>
        <source>Darker</source>
        <translation type="obsolete">Plus sombre</translation>
    </message>
    <message>
        <source>Lighter</source>
        <translation type="obsolete">Plus clair</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systemdefinition.h" line="74"/>
        <source>System</source>
        <translation>Système</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systemdefinition.h" line="77"/>
        <source>Restart, stop the computer or logout the current user</source>
        <translation>Redémarre, arrête l&apos;ordinateur ou déconnecte l&apos;utilisateur courant</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation type="obsolete">Déconnexion</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="obsolete">Redémarrage</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation type="obsolete">Arrêt</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation type="obsolete">Demander</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="obsolete">Normal</translation>
    </message>
    <message>
        <source>Force</source>
        <translation type="obsolete">Forcer</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/openurldefinition.h" line="51"/>
        <source>Open URL</source>
        <translation>Ouvrir URL</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/openurldefinition.h" line="54"/>
        <source>Opens an URL</source>
        <translation>Ouvre une URL</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="67"/>
        <source>Detached command</source>
        <translation>Commande détachée</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/detachedcommanddefinition.h" line="70"/>
        <source>Executes a detached command</source>
        <translation>Exécute une commande détachée</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="87"/>
        <source>Play sound</source>
        <translation>Lire son</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/playsounddefinition.h" line="90"/>
        <source>Plays a sound</source>
        <translation>Lit un son</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="160"/>
        <source>Find image</source>
        <translation>Trouver image</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/findimagedefinition.h" line="163"/>
        <source>Finds an image on the screen, on a window or on another image</source>
        <translation>Trouve une image sur l&apos;écran, dans une fenêtre ou dans une autre image</translation>
    </message>
</context>
<context>
    <name>SystemInstance::modes</name>
    <message>
        <source>Ask</source>
        <translation type="obsolete">Demander</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="obsolete">Normal</translation>
    </message>
    <message>
        <source>Force</source>
        <translation type="obsolete">Forcer</translation>
    </message>
</context>
<context>
    <name>SystemInstance::operations</name>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="29"/>
        <source>Logout</source>
        <translation>Déconnexion</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="30"/>
        <source>Reboot</source>
        <translation>Redémarrage</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="31"/>
        <source>Shutdown</source>
        <translation>Arrêt</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="32"/>
        <source>Suspend</source>
        <translation>Mise en veille</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="33"/>
        <source>Hibernate</source>
        <translation>Hiberner</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="34"/>
        <source>Lock screen</source>
        <translation>Verrouiller l&apos;écran</translation>
    </message>
    <message>
        <location filename="../actions/actionpacksystem/actions/systeminstance.cpp" line="35"/>
        <source>Start screen saver</source>
        <translation>Démarrer l&apos;écran de veille</translation>
    </message>
</context>
</TS>
